ENTRY(_start)

MEMORY
{
	FLASH	: ORIGIN = 0x50000000, LENGTH = 0x00800000
	SRAM	: ORIGIN = 0x00000000, LENGTH = 0x00010000
	DRAM	: ORIGIN = 0x00010000, LENGTH = 0x03ff0000
}

SECTIONS
{
	. = 0x50000000;

	/* boot code: not relocated */
	.init BLOCK(32):
	{
		*(.init)
		setup_flash.o(*)
	} >FLASH

	
	__text_start_flash = .;
	. = 0x00001000;

	.text BLOCK(32): AT(__text_start_flash)
	{
		__text_start = ABSOLUTE(.);

		*(.ram.boot)		/* must come first */
		*(.hermit.version)

		*(.text)		/* program text (code) */
		*(.text.*)		/* annotated text sections */
		*(.stub)
		*(.gnu.warning)
		*(.gnu.linkonce.t*)
		*(.glue_7t)
		*(.glue_7)
		*(.rodata)		/* read-only data */
		*(.rodata.*)		/* read-only data */
		*(.gnu.linkonce.r*)
		*(.rodata1)		/* read-only data */
		*(.sdata2)

		*(.eh_frame)
		*(.gcc_except_table)
		*(.got)			/* global offset table */
		*(.dynamic)

		*(.sdata)
		*(.sdata.*)
		*(.gnu.linkonce.s.*)

		*(.got.plt)

		__text_end = ABSOLUTE(.);
	} >SRAM =0

	__data_start_flash = LOADADDR(.text) + SIZEOF(.text);

	.data BLOCK(32): AT(__data_start_flash)
	{
		__data_start = ABSOLUTE(.);
		*(.data)		/* initialized writeable data */
		*(.data.*)		/* initialized writeable data */
		*(.gnu.linkonce.d*)
		*(.data1)
		__data_end = ABSOLUTE(.);
	} >SRAM =0

	/* .bss: uninitialized data (must be zeroed) */
	.bss BLOCK(32): AT(__bss_start)
	{
		__bss_start = ABSOLUTE(.);
		*(.sbss)
		*(.dynsbss)
		*(.sbss.*)
		*(.sbss2)
		*(.scommon)
		*(.bss)			/* uninitialized data (zeroed) */
		*(.dynbss)
		*(.bss.*)		/* uninitialized data (zeroed) */
		*(COMMON)
		__bss_end = ABSOLUTE(.);
	} >SRAM

	/* .unused: stuff we don't want in the loader */
	.unused :
	{
		*(.ctors)		/* constructors */
		*(.dtors)		/* destructors */
		*(.init)		/* initialization code */
		*(.fini)		/* termination code */
		*(.note.ABI-tag)

		*(.interp)		/* path name of program interpreter */
		*(.hash)		/* symbol hash table */
		*(.dynsym)		/* dynamic linking symbol table */
		*(.dynstr)
		*(.gnu.version)
		*(.gnu.version_d)
		*(.gnu.version_r)
		*(.plt)			/* procedure linkage table */

		*(.rel.init)		/* relocation information... */
		*(.rela.init)
		*(.rel.text)
		*(.rela.text)
		*(.rel.fini)
		*(.rela.fini)
		*(.rel.rodata)
		*(.rela.rodata)
		*(.rel.data)
		*(.rela.data)
		*(.rel.ctors)
		*(.rela.ctors)
		*(.rel.dtors)
		*(.rela.dtors)
		*(.rel.got)
		*(.rela.got)
		*(.rel.sdata)
		*(.rela.sdata)
		*(.rel.sbss)
		*(.rela.sbss)
		*(.rel.sdata2)
		*(.rela.sdata2)
		*(.rel.sbss2)
		*(.rela.sbss2)
		*(.rel.bss)
		*(.rela.bss)
		*(.rel.plt)
		*(.rela.plt)

		*(.stab)		/* symbol table (debugging)... */
		*(.stabstr)
		*(.stab.excl)
		*(.stab.exclstr)
		*(.stab.index)
		*(.stab.indexstr)
	}
}
