
#ifndef _REGMAP_H_
#define _REGMAP_H_

#define readl(a) (*(volatile unsigned int *)(a))
#define readb(a) (*(volatile unsigned char *)(a))
#define writel(a, v) (*(volatile unsigned int *)(a) = (unsigned int)v)
#define writeb(a, v) (*(volatile unsigned char *)(a) = (unsigned char)v)

//////////////////////////////////////////////////////////////////////////////
#define REG_MISC_BASE		(0x60000000)
#define REG_MISC(offset)	(REG_MISC_BASE + offset)

#define MISC_IDE_STAT		(0x00000004)

#define F_MISC_IDE_DETECT	(0x00000002)

//////////////////////////////////////////////////////////////////////////////
#define REG_SER_BASE		(0x90200000)
#define REG_SER(offset)		(REG_SER_BASE + offset)

#define SER_CTRL_A		(0x00000040)
#define SER_CTRL_B		(0x00000044)
#define SER_STAT_A		(0x00000048)
#define SER_BITRATE		(0x0000004c)
#define SER_FIFO		(0x00000050)
#define SER_RX_BUF_TIMER	(0x00000054)

#define F_SER_STAT_RRDY		(0x00000800)
#define F_SER_STAT_RBC		(0x00000200)
#define F_SER_STAT_TRDY		(0x00000008)
#define F_SER_STAT_TEMPTY	(0x00000001)

//////////////////////////////////////////////////////////////////////////////
#define REG_BBUS_BASE		(0x90600000)
#define REG_BBUS(offset)	(REG_BBUS_BASE + offset)

#define BBUS_MASTER_RESET	(0x00000000)
#define BBUS_GPIO_CFG_2		(0x00000014)
#define BBUS_GPIO_CFG_3		(0x00000018)
#define BBUS_GPIO_CFG_4		(0x0000001c)
#define BBUS_GPIO_CFG_6		(0x00000024)
#define BBUS_GPIO_CTRL_2	(0x00000034)
#define BBUS_GPIO_STAT_1	(0x00000040)

//////////////////////////////////////////////////////////////////////////////
#define REG_MEM_BASE		(0xa0700000)
#define REG_MEM(offset)		(REG_MEM_BASE + offset)

#define MEM_CTRL		(0x00000000)
#define MEM_STATUS		(0x00000004)
#define MEM_CFG			(0x00000008)
#define MEM_DYN_CTRL		(0x00000020)
#define MEM_DYN_REFRESH		(0x00000024)
#define MEM_DYN_READ_CFG	(0x00000028)
#define MEM_DYN_TRP		(0x00000030)
#define MEM_DYN_TRAS		(0x00000034)
#define MEM_DYN_TSREX		(0x00000038)
#define MEM_DYN_TAPR		(0x0000003c)
#define MEM_DYN_TDAL		(0x00000040)
#define MEM_DYN_TWR		(0x00000044)
#define MEM_DYN_TRC		(0x00000048)
#define MEM_DYN_TRFC		(0x0000004C)
#define MEM_DYN_TXSR		(0x00000050)
#define MEM_DYN_TRRD		(0x00000054)
#define MEM_DYN_TMRD		(0x00000058)

#define MEM_DYN_CFG_0		(0x00000100)
#define MEM_DYN_RAS_CAS_0	(0x00000104)
#define MEM_DYN_CFG_1		(0x00000120)
#define MEM_DYN_RAS_CAS_1	(0x00000124)
#define MEM_DYN_CFG_2		(0x00000140)
#define MEM_DYN_RAS_CAS_2	(0x00000144)
#define MEM_DYN_CFG_3		(0x00000160)
#define MEM_DYN_RAS_CAS_3	(0x00000164)

#define MEM_STATIC_EXT_WAIT	(0x00000080)
#define MEM_STATIC_CFG_0	(0x00000200)
#define MEM_STATIC_WAIT_WEN_0	(0x00000204)
#define MEM_STATIC_WAIT_OEN_0	(0x00000208)
#define MEM_STATIC_WAIT_RD_0	(0x0000020c)
#define MEM_STATIC_WAIT_PAGE_0	(0x00000210)
#define MEM_STATIC_WAIT_WR_0	(0x00000214)
#define MEM_STATIC_WAIT_TURN_0	(0x00000218)
#define MEM_STATIC_CFG_1	(0x00000220)
#define MEM_STATIC_WAIT_WEN_1	(0x00000224)
#define MEM_STATIC_WAIT_OEN_1	(0x00000228)
#define MEM_STATIC_WAIT_RD_1	(0x0000022c)
#define MEM_STATIC_WAIT_PAGE_1	(0x00000230)
#define MEM_STATIC_WAIT_WR_1	(0x00000234)
#define MEM_STATIC_WAIT_TURN_1	(0x00000238)
#define MEM_STATIC_CFG_2	(0x00000240)
#define MEM_STATIC_WAIT_WEN_2	(0x00000244)
#define MEM_STATIC_WAIT_OEN_2	(0x00000248)
#define MEM_STATIC_WAIT_RD_2	(0x0000024c)
#define MEM_STATIC_WAIT_PAGE_2	(0x00000250)
#define MEM_STATIC_WAIT_WR_2	(0x00000254)
#define MEM_STATIC_WAIT_TURN_2	(0x00000258)
#define MEM_STATIC_CFG_3	(0x00000260)
#define MEM_STATIC_WAIT_WEN_3	(0x00000264)
#define MEM_STATIC_WAIT_OEN_3	(0x00000268)
#define MEM_STATIC_WAIT_RD_3	(0x0000026c)
#define MEM_STATIC_WAIT_PAGE_3	(0x00000270)
#define MEM_STATIC_WAIT_WR_3	(0x00000274)
#define MEM_STATIC_WAIT_TURN_3	(0x00000278)

//////////////////////////////////////////////////////////////////////////////
#define REG_SYS_BASE		(0xa0900000)
#define REG_SYS(offset)		(REG_SYS_BASE + offset)

#define SYS_AHB_GEN		(0x00000000)
#define SYS_BRC_0		(0x00000004)
#define SYS_BRC_1		(0x00000008)
#define SYS_BRC_2		(0x0000000c)
#define SYS_BRC_3		(0x00000010)
#define SYS_TIMER_COUNT_3	(0x00000050)
#define SYS_TIMER_READ_3	(0x00000090)
#define SYS_PLL			(0x00000188)
#define SYS_TIMER_CTRL_3	(0x0000019c)
#define SYS_CS_STATIC_BASE_2	(0x00000200)
#define SYS_CS_STATIC_MASK_2	(0x00000204)

#endif
