
#include "regmap.h"
#include "serial.h"

#define T_1MS 0x18600

int getchar(int timeout)
{
  static unsigned long data = 0;
  static unsigned char rxfdb = 0;
  
  if(!rxfdb){
    unsigned long status;

    writel(REG_SYS(SYS_TIMER_CTRL_3), 0x8042); /* CPU/2 = 100MHz*/
    do{
      if(readl(REG_SYS(SYS_TIMER_READ_3)) > (T_1MS * timeout))
	goto __timeout;

      status = readl(REG_SER(SER_STAT_A));
      if(status & F_SER_STAT_RBC){
	writel(REG_SER(SER_STAT_A), F_SER_STAT_RBC);
      }
    }while(!(status & F_SER_STAT_RRDY));

    writel(REG_SYS(SYS_TIMER_CTRL_3), 0x0);

    rxfdb = ((status & 0x00300000) >> 20);
    data = readl(REG_SER(SER_FIFO));
    if(!rxfdb){
      rxfdb = 4;
    }
  }else{
    data >>= 8;
  }
  rxfdb--;
  return (int)(data & 0xff);

 __timeout:
  writel(REG_SYS(SYS_TIMER_CTRL_3), 0x0);
  return -1;
}

void putchar(char c)
{
  while(!(readl(REG_SER(SER_STAT_A)) & F_SER_STAT_TRDY));
  writeb(REG_SER(SER_FIFO), c);
}

void print(char *str)
{
  int i = 0;
  while(str[i] != 0)
    putchar(str[i++]);
}

void flush(void)
{
  while(!(readl(REG_SER(SER_STAT_A)) & F_SER_STAT_TEMPTY));
}

void set_baud(int speed)
{
  unsigned int ctrla, baud;
  ctrla = readl(REG_SER(SER_CTRL_A));
  writel(REG_SER(SER_CTRL_A), ctrla & ~0x80000000);

  baud = readl(REG_SER(SER_BITRATE)) & ~0x00007fff;

  switch(speed){
  case 9600:
    baud |= 95;
    break;
  case 115200:
  default:
    baud |= 7;
    break;
  }
  writel(REG_SER(SER_BITRATE), baud);
  writel(REG_SER(SER_CTRL_A), ctrla);
}
